@@ -3,12 +3,12 @@ from . import (
     annotated,
     any,
     bytes,
-    callable,
     complex,
     dataclass,
+    datetime,
     defaultdict,
     enum,
-    iterator,
+    generic,
     literal,
     logger,
     mapping,
@@ -32,12 +32,12 @@ __all__ = (
     'annotated',
     'any',
     'bytes',
-    'callable',
     'complex',
     'dataclass',
+    'datetime',
     'defaultdict',
     'enum',
-    'iterator',
+    'generic',
     'literal',
     'logger',
     'mapping',
